@@ -15,7 +15,7 @@ class DefaultsDict(UserDict):
     def __init__(
         self,
         default_factories: Dict[Any, Callable[[], Any]] = None,
-        dict_: dict = None,
+        data: dict = None,
         **kwargs: Any
     ) -> None:
         """Initializes the dictionary.
@@ -24,15 +24,13 @@ class DefaultsDict(UserDict):
         ----------
         default_factories : Dict[Any, Callable[[], Any]], None
             The dictionary of functions to call if keys are missing.
-        dict_ : dict, None
+        data : dict, None
             The dictionary to initialize with.
         kwargs : Any
             The keyword arguments to initialize the dictionary with.
         """
-        if default_factories is None:
-            default_factories = {}
-        self.default_factories = default_factories
-        super().__init__(dict_, **kwargs)
+        self.default_factories = default_factories or {}
+        super().__init__(data, **kwargs)
 
     def __missing__(self, key: str) -> Any:
         self.data[key] = self.default_factories[key]()
